#
# spec file for package i3lock
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014 B1 Systems GmbH, Vohburg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Please submit bugfixes or comments via http://bugs.opensuse.org/
Name:           i3lock
Version:        2.15
Release:        1.2
Summary:        Screen Locker for the i3 Window Manager
License:        BSD-3-Clause
URL:            https://i3wm.org/i3lock/
Source:         https://i3wm.org/i3lock/%{name}-%{version}.tar.xz
# borrowed from gnome-icon-theme
Source2:        i3lock-icon.png
Source3:        xlock.sh
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  meson
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(xcb-atom)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-xrm)
BuildRequires:  pkgconfig(xkbcommon) >= 0.5.0
BuildRequires:  pkgconfig(xkbcommon-x11)

%description
i3lock is a simple screen locker like slock. After starting it, you will see a
white screen (you can configure the color/an image). You can return to your
screen by entering your password.

%package xlock-compat
Summary:        Xlock-compatibility script which calls i3lock
Requires:       ImageMagick
Requires:       xdpyinfo
Conflicts:      xlockmore

%description xlock-compat
This package provides a script %{_bindir}/xlock which calls i3lock to lock your screen.
This is handy for hard-coded screen-saver invocations e.g. in XFCE4, so you can use
i3lock instead of xlock with them.

%prep
%autosetup -p 1

%build
export CFLAGS="%{optflags}"
%meson
%meson_build

%install
%meson_install

install -D -m0644 %{name}.1 "%{buildroot}%{_mandir}/man1/%{name}.1"
install -D -m0644 %{SOURCE2} %{buildroot}%{_datadir}/i3lock-xlock-compat/i3lock-icon.png
install -m0755 %{SOURCE3} %{buildroot}/%{_bindir}/xlock
%if 0%{?suse_version} >= 1550
mkdir -p %{buildroot}%{_pam_vendordir}
mv %{buildroot}%{_sysconfdir}/pam.d/* %{buildroot}%{_pam_vendordir}/
%endif

%pre
for i in pam.d/i3lock ; do
  test -f /etc/${i}.rpmsave && mv -v /etc/${i}.rpmsave /etc/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/etc.
for i in pam.d/i3lock ; do
  test -f /etc/${i}.rpmsave && mv -v /etc/${i}.rpmsave /etc/${i} ||:
done

%files xlock-compat
%{_bindir}/xlock
%{_datadir}/%{name}-xlock-compat

%files
%license LICENSE
%doc CHANGELOG README.md
%if 0%{?suse_version} >= 1550
%{_pam_vendordir}/%{name}
%else
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%endif
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Wed Apr 17 2024 Avindra Goolcharan <avindra@opensuse.org>
- remove unneeded %%check section
* Fri Apr 12 2024 ming li <mli@suse.com>
- update to 2.15:
  * unlock indicator: display current keyboard layout when
    user types password (with --show-keyboard-layout flag).
* Fri Jun 23 2023 Avindra Goolcharan <avindra@opensuse.org>
- update to 2.14.1:
  * unlock indicator: display only caps lock and num lock, not all
    modifiers like shift (which can leak information about your
    password to bystanders)
- includes 2.14:
  * Change default background color to #a3a3a3 See
    https://github.com/i3/i3lock/pull/300 for extensive discussion
    and rationale for this change.
  * Recommend using xss-lock to start i3lock in the README
    and i3lock.1 man page. xss-lock is the best way to ensure
    your screen truly is locked before your computer suspends
  * Display modifier key warning before unlocking, too,
    not just on failed attempts like before
  * Switch build system from autotools to meson
* Tue Aug  9 2022 Thorsten Kukuk <kukuk@suse.com>
- Use %%_pam_vendordir
* Sun Dec 27 2020 Matthias Eliasson <elimat@opensuse.org>
- update to 2.13
  * Throw error when trying to start on Wayland
  * Use explicit_bzero() where available, not just on OpenBSD
  * avoid pixmap allocations in the redraw path
  * make --debug output go to stderr
  * unlock_indicator.c: fix build failure against gcc-10
  * fix: call pam_end in cleanup in main, not in event loop
  * set _NET_WM_BYPASS_COMPOSITOR hint to avoid flickering
- drop patch: 0001-unlock_indicator.c-fix-build-failure-against-gcc-10.patch fixed upstream
* Mon Sep  7 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Install pam configuration to /usr/etc/pam.d on suse_version >=
  1500 (https://en.opensuse.org/openSUSE:Packaging_UsrEtc#pam.2Fpam-config).
- Add pre/posttrans scripts to ensure user modified
  /etc/pam.d/i3lock survives our move to /usr/etc (and user
  modification in /etc/pam.d wins over /usr/etc/pam.d)
* Sat Jun  6 2020 Matthias Eliasson <elimat@opensuse.org>
- update to 2.12
  * remove stray \n from error messages
  * capitalize unlock indicator contents
  * set WM_CLASS property
  * reference modifier as “Super”, not “Win”
  * add --raw option to read image as raw bytes
- run spec-cleaner
  * Remove Gropus
- add patch 0001-unlock_indicator.c-fix-build-failure-against-gcc-10.patch
  to fix builds with gcc10
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libudev1 BuildRequires: buildrequiring a library (and not a
  relevant devel package) can't ever be correct.
* Tue Oct 23 2018 Avindra Goolcharan <aavindraa@gmail.com>
- update to 2.11.1
  * fix dist tarball by including I3LOCK_VERSION
- includes 2.11
  * Display an error when backspace is pressed without any input
  * Print an error when a non-PNG file is opened (i3lock only supports
    PNG files)
  * Don’t unnecessarily check the xcb_connect return value, it is
    known never to be NULL
  * Fix memory leak when grabbing fails
  * Respect Xft.dpi for determining the unlock indicator’s scale factor
  * Discard pending password verification attempts when a new
    password is entered
  * Switch to autotools
- run spec-cleaner
* Wed Feb  7 2018 avindra@opensuse.org
- switch to https urls
- cleanup spec file
* Sun Nov 26 2017 aavindraa@gmail.com
- update to 2.10
  * Only use -lpam when not on OpenBSD
  * locale: treat empty string same as unset
  * Fix overwrite of getopt optind
  * Immediately hide the unlock indicator after ESC / C-u
  * Measure wall-clock time instead of CPU time for “locking” indicator.
  * SetInputFocus to the i3lock window to force-close context menus
  * Use RandR for learning about attached monitors
* Wed Nov  8 2017 kukuk@suse.de
- Remove obsolete pam-modules requires
* Tue Sep  5 2017 aavindraa@gmail.com
- update to 2.9.1
- Fix version number mechanism
- Revert the fix for composited notifications, as it causes more issues than
  it solves:
* Sun Jun 11 2017 mimi.vx@gmail.com
- drop i3lock-2.5-use-unix2_chkpwd.diff
- use default pam config - drop i3lock.pam
* Sat Jun 10 2017 mimi.vx@gmail.com
- update to 2.9
- refresh i3lock-2.5-use-unix2_chkpwd.diff
  * Removed obsolete inactivity timeout
  * Set font face
  * Automatically unlock (without having to press <Enter>) one attempt which was
  entered while authenticating
  * Stop leaking the image_path dup
  * Displaying locking message when grabbing the pointer/keyboard
  * Display error message when locking failed
  * Add Enter on C-m
  * Change input slices to be exactly pi/3 in size instead of slightly more
  * Fix covering of composited notifications using the XComposite extension
  * Remove last traces of DPMS
* Sun Dec 18 2016 mimi.vx@gmail.com
- update to 2.8
- refresh i3lock-2.5-use-unix2_chkpwd.diff
  * Remove DPMS support in favor of a wrapper script and xset
  * Indicate that the --inactivity-timeout option takes an argument
  * fix pam_securetty: set PAM_TTY to getenv("DISPLAY")
  * Eat XKB_KEY_Delete and XKB_KEY_KP_Delete
  * Show unlock indicator if password was entered during PAM verification
  * Allow CTRL+J as enter and CTRL+H as backspace
  * Flush xcb connection after opening fullscreen window
  * Add support for `xss-lock --transfer-sleep-lock'
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 2.7
- refresh i3lock-2.5-use-unix2_chkpwd.diff
  * Die when the X11 connection breaks during runtime
  * Implement logging the number of failed attempts
  * Ignore password validation is pam is in wrong state
  * Get current user with getpwuid() instead of using $ENV{USER}
  * Add support for Compose and dead-keys with libxkbcommon.
  Requires libxkbcommon ≥ 0.5.0
  * Format the source using clang-format.
  * Refresh pam credentials on successful authentication (for Kerberos and the
  like)
  * List pressed modifiers on failed authentication
  * Only redraw the screen if the unlock indicator is actually used
  * Make pkg-config configurable for cross-compilation
* Sat May  9 2015 mpluskal@suse.com
- Add missing dependency on xdpyinfo (boo#930330)
* Mon Jan 19 2015 p.drouand@gmail.com
- Update to version 2.6
  * NEW DEPENDENCY: use libxkbcommon-x11 instead of libX11
    This helps us get rid of all code that directly uses libX11
  * Use cairo_status_to_string for descriptive errors.
  * Add `-e` option to not validate empty password.
  * Bugfix: update the initial keyboard modifier state (Thanks lee, Ran)
  * Re-raise i3lock when obscured in a separate process
  * Turn on the screen on successful authentication
  * Delay to turn off the screen after wrong passwd
  * Discard half-entered passwd after some inactivity
  * Ignore empty passwd after repeated Enter keypress
  * Scale the unlock indicator (for retina displays)
- Replace xorg-x11-devel with pkgconfig(xkbcommon-x11); follow
  upstream changes
- Add pkgconfig(cairo) and pkgconfig(xcb-atom) requirements; new
  upstream dependencies
- Remove redundant %%clean section
* Thu Mar 20 2014 seife+obs@b1-systems.com
- add i3lock-xlock-compat package which provides /usr/bin/xlock
  for drop-in replacement in e.g. xflock4
* Mon Feb 17 2014 seife+obs@b1-systems.com
- readd the pam config file, which is still needed by unix2_chkpwd
  (I should read the man page more thoroughly next time)
* Sat Feb 15 2014 seife+obs@b1-systems.com
- add patch to use unix2_chkpwd instead of pam directly (which
  would need to make i3lock sgid shadow to work for non-root)
  * i3lock-2.5-use-unix2_chkpwd.diff
* Sat Feb 15 2014 seife+obs@b1-systems.com
- update to version 2.5:
  * NEW DEPENDENCY: Use libxkbcommon for input handling
    This makes input handling much better for many edge cases.
  * Bugfix: fix argument parsing on ARM (s/char/int/)
  * Bugfix: free(reply) to avoid memory leak
  * Bugfix: Use ev_loop_fork after fork, fixes forking on kqueue based OSes
  * Bugfix: Fix centering the indicator in the no-xinerama case
  * promote the "could not load image" message from debug to normal
  * s/pam_message/pam_response/ (Thanks Tucos)
  * remove support for NOLIBCAIRO, cairo-xcb is widespread by now
  * Allow XKB_KEY_XF86ScreenSaver as synonym for enter
    This keysym is generated on convertible tablets by pressing a hardware
    lock/unlock button.
  * Allow passwordless PAM conversations (e.g. fingerprint)
  * Add ctrl+u password reset
  * Set window name to i3lock
* Thu Mar  7 2013 toganm@opensuse.org
- Add xcb-keysyms  xcb-image to BuildRequires
- cleanup spec
* Wed Nov 14 2012 pascal.bleser@opensuse.org
- initial version (2.4.1)
